===============================
spath.py
===============================


.. image:: https://img.shields.io/pypi/v/spath.svg
        :target: https://pypi.python.org/pypi/spath


This package provides a ``Path`` class extending ``Path`` from
Jason R Coomb's `path.py`_ with some convenience methods related
to image and data processing.


* Free software: BSD license


Credits
---------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _`path.py`: https://github.com/jaraco/path.py
.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
